==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersConfidenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eq The equal-to condition to be applied to a single field when querying for findings, provided as a String.
 * @property gte The greater-than-equal condition to be applied to a single field when querying for findings, provided as a String.
 * @property lte The less-than-equal condition to be applied to a single field when querying for findings, provided as a String.
 */
public data class InsightFiltersConfidenceArgs(
    public val eq: Output<String>? = null,
    public val gte: Output<String>? = null,
    public val lte: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs.builder()
            .eq(eq?.applyValue({ args0 -> args0 }))
            .gte(gte?.applyValue({ args0 -> args0 }))
            .lte(lte?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersConfidenceArgs].
 */
@PulumiTagMarker
public class InsightFiltersConfidenceArgsBuilder internal constructor() {
    private var eq: Output<String>? = null

    private var gte: Output<String>? = null

    private var lte: Output<String>? = null

    /**
     * @param value The equal-to condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("wbxvajhifeelqmva")
    public suspend fun eq(`value`: Output<String>) {
        this.eq = value
    }

    /**
     * @param value The greater-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("tyxxcyjfxhmanxqr")
    public suspend fun gte(`value`: Output<String>) {
        this.gte = value
    }

    /**
     * @param value The less-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("bktyrvjylffopvna")
    public suspend fun lte(`value`: Output<String>) {
        this.lte = value
    }

    /**
     * @param value The equal-to condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("wvsrdqxeqwgkiane")
    public suspend fun eq(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eq = mapped
    }

    /**
     * @param value The greater-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("mbhuswgejommujsm")
    public suspend fun gte(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gte = mapped
    }

    /**
     * @param value The less-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("apecedgpdblyxbpu")
    public suspend fun lte(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lte = mapped
    }

    internal fun build(): InsightFiltersConfidenceArgs = InsightFiltersConfidenceArgs(
        eq = eq,
        gte = gte,
        lte = lte,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersConfidenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property eq The equal-to condition to be applied to a single field when querying for findings, provided as a String.
 * @property gte The greater-than-equal condition to be applied to a single field when querying for findings, provided as a String.
 * @property lte The less-than-equal condition to be applied to a single field when querying for findings, provided as a String.
 */
public data class InsightFiltersConfidenceArgs(
    public val eq: Output<String>? = null,
    public val gte: Output<String>? = null,
    public val lte: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersConfidenceArgs.builder()
            .eq(eq?.applyValue({ args0 -> args0 }))
            .gte(gte?.applyValue({ args0 -> args0 }))
            .lte(lte?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersConfidenceArgs].
 */
@PulumiTagMarker
public class InsightFiltersConfidenceArgsBuilder internal constructor() {
    private var eq: Output<String>? = null

    private var gte: Output<String>? = null

    private var lte: Output<String>? = null

    /**
     * @param value The equal-to condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("wiykbgpgdadmnvsk")
    public suspend fun eq(`value`: Output<String>) {
        this.eq = value
    }

    /**
     * @param value The greater-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("hckobwenphvcspok")
    public suspend fun gte(`value`: Output<String>) {
        this.gte = value
    }

    /**
     * @param value The less-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("maotxatuiuoxvkhx")
    public suspend fun lte(`value`: Output<String>) {
        this.lte = value
    }

    /**
     * @param value The equal-to condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("roprdylcqbjuagbb")
    public suspend fun eq(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eq = mapped
    }

    /**
     * @param value The greater-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("mpcfwbwvpdhkdggl")
    public suspend fun gte(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gte = mapped
    }

    /**
     * @param value The less-than-equal condition to be applied to a single field when querying for findings, provided as a String.
     */
    @JvmName("lxqdbsjphogroiqx")
    public suspend fun lte(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lte = mapped
    }

    internal fun build(): InsightFiltersConfidenceArgs = InsightFiltersConfidenceArgs(
        eq = eq,
        gte = gte,
        lte = lte,
    )
}
